@@ -26,14 +26,14 @@
 
 This AWS Solutions Construct implements an AWS Lambda function connected to an Amazon SQS queue.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { LambdaToSqs } = require('@aws-solutions-constructs/aws-lambda-sqs');
+import { LambdaToSqs, LambdaToSqsProps } from "@aws-solutions-constructs/aws-lambda-sqs";
 
-new LambdaToSqs(stack, 'LambdaToSqsPattern', {
+new LambdaToSqs(this, 'LambdaToSqsPattern', {
     lambdaFunctionProps: {
-        runtime: lambda.Runtime.NODEJS_10_X,
+        runtime: lambda.Runtime.NODEJS_12_X,
         handler: 'index.handler',
         code: lambda.Code.asset(`${__dirname}/lambda`)
     }
@@ -107,8 +107,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -130,11 +130,11 @@ class LambdaToSqs(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
-        enable_queue_purging: typing.Optional[bool] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        enable_queue_purging: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -173,17 +173,17 @@ class LambdaToSqs(
 
         jsii.create(LambdaToSqs, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return jsii.get(self, "sqsQueue")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return jsii.get(self, "deadLetterQueue")
@@ -208,8 +208,8 @@ class LambdaToSqsProps:
         self,
         *,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
-        enable_queue_purging: typing.Optional[bool] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+        enable_queue_purging: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -235,7 +235,7 @@ class LambdaToSqsProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
         if deploy_dead_letter_queue is not None:
@@ -260,25 +260,28 @@ class LambdaToSqsProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dead_letter_queue_props")
+        result = self._values.get("dead_letter_queue_props")
+        return result
 
     @builtins.property
-    def deploy_dead_letter_queue(self) -> typing.Optional[bool]:
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy a secondary queue to be used as a dead letter queue.
 
         default
         :default: - true.
         """
-        return self._values.get("deploy_dead_letter_queue")
+        result = self._values.get("deploy_dead_letter_queue")
+        return result
 
     @builtins.property
-    def enable_queue_purging(self) -> typing.Optional[bool]:
+    def enable_queue_purging(self) -> typing.Optional[builtins.bool]:
         """Whether to grant additional permissions to the Lambda function enabling it to purge the SQS queue.
 
         default
         :default: - "false", disabled by default.
         """
-        return self._values.get("enable_queue_purging")
+        result = self._values.get("enable_queue_purging")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -287,7 +290,8 @@ class LambdaToSqsProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -296,7 +300,8 @@ class LambdaToSqsProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("existing_queue_obj")
+        result = self._values.get("existing_queue_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -307,7 +312,8 @@ class LambdaToSqsProps:
         default
         :default: - Default properties are used.
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -316,7 +322,8 @@ class LambdaToSqsProps:
         default
         :default: - required field if deployDeadLetterQueue=true.
         """
-        return self._values.get("max_receive_count")
+        result = self._values.get("max_receive_count")
+        return result
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -325,12 +332,13 @@ class LambdaToSqsProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("queue_props")
+        result = self._values.get("queue_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
